@@ -1095,7 +1095,7 @@ class MarkdownFlow:
 
         # 5. Output language anchoring (bottom - final reminder)
         if self._output_language:
-            system_parts.append(OUTPUT_LANGUAGE_INSTRUCTION_BOTTOM.format(self._output_language, self._output_language))
+            system_parts.append(OUTPUT_LANGUAGE_INSTRUCTION_BOTTOM.format(self._output_language))
 
         # Combine all parts and add as system message
         if system_parts:
@@ -1110,16 +1110,22 @@ class MarkdownFlow:
 
         # Build user message
         # Step 1: If has preserved content, add inline processing instruction (Solution A: minimal inline instruction)
+        # Build User Message (layer by layer from inside to outside)
         user_content = block_content
+
+        # Step 1: If has preserved content, add inline processing instruction
         if has_preserved_content:
-            # Add minimal instruction at top of user message, close to the processing target,
-            # naturally higher priority than system rules
-            instruction = "[INSTRUCTION: Remove <preserve_or_translate> tags, keep content with all formatting and position. Use same language as rest of this message.]\n\n"
+            if self._output_language:
+                # When output language is set: explicitly require translation of tag content
+                instruction = f"[INSTRUCTION: Remove <preserve_or_translate> tags, translate content inside tags to {self._output_language}, keep formatting.]\n\n"
+            else:
+                # When no output language: keep original language
+                instruction = "[INSTRUCTION: Remove <preserve_or_translate> tags, keep content with all formatting and position.]\n\n"
             user_content = instruction + block_content
 
-        # Step 2: If has outputLanguage, add language wrapper (third layer anchoring)
+        # Step 2: If has outputLanguage, add language wrapper (outermost layer, highest priority)
         if self._output_language:
-            user_content = f"[Language: {self._output_language}]\n{user_content}\n[Remember: Output in {self._output_language}]"
+            user_content = f"🚨 OUTPUT: 100% {self._output_language} - Translate ALL non-{self._output_language} words/phrases to {self._output_language} 🚨\n\n{user_content}"
 
         # Add processed content as user message (as instruction to LLM)
         messages.append({"role": "user", "content": user_content})
@@ -1184,7 +1190,7 @@ class MarkdownFlow:
             system_parts.append(INTERACTION_PROMPT_BASE + "\n" + INTERACTION_PROMPT_WITH_TRANSLATION)
 
             # 3. Output language anchoring (bottom)
-            system_parts.append(OUTPUT_LANGUAGE_INSTRUCTION_BOTTOM.format(self._output_language, self._output_language))
+            system_parts.append(OUTPUT_LANGUAGE_INSTRUCTION_BOTTOM.format(self._output_language))
         else:
             # No translation scenario: use default no-translation prompt
             # Use default prompt (includes Base + NoTranslation)
@@ -1362,7 +1368,7 @@ class MarkdownFlow:
         # 3. Output language anchoring (bottom - if output language is set)
         if has_language_requirement:
             system_parts.append("")
-            system_parts.append(OUTPUT_LANGUAGE_INSTRUCTION_BOTTOM.format(self._output_language, self._output_language))
+            system_parts.append(OUTPUT_LANGUAGE_INSTRUCTION_BOTTOM.format(self._output_language))
 
         system_content = "\n".join(system_parts)
 
